var PLAYER_FACTORY_VERSION = '2.1';
// defines empty functions that get filled with the load-Promise callbacks
var loadRequestPromiseResolve = function() {};
var loadRequestPromiseReject = function() {};
function FacadeBase() {
   this.handshakeVersion = function _(apiFacadeVersion) {
      return PLAYER_FACTORY_VERSION;
   };
   /**
    * @param {string} url Media file URI
    * @param {Boolean} disableSeeking Wether the requested source can be seeked back and forth
    * @returns {Promise} Either resolves if the player accepted the play request or not
    */
   this.load = function _(url, disableSeeking = false) {
      return new Promise(function(resolve, reject) {
         loadRequestPromiseResolve = resolve;
         loadRequestPromiseReject = reject;
         var arguments = {'url': url, 'disableSeeking': disableSeeking};
         var accept = callNativeFunction("loadAdWithUrlString:disableSeeking:", arguments);
         // the native code should then respond by calling either
         //  callJSFunction("loadRequestPromiseResolve")
         //  callJSFunction("loadRequestPromiseReject")
         // depending on whether the MediaFile could be loaded (resolve) or not (reject).
      });
   };
   this.addEventListener = function _(event, callback) {
      let eventDispatcher = getEventDispatcher();
      eventDispatcher.addEventListener(event, callback);
   };
   this.removeEventListener = function _(event, callback) {
      let eventDispatcher = getEventDispatcher();
      eventDispatcher.removeEventListener(event, callback);
   };
   this.onEventCallback = function _(event) {
      var message = {'name':"onEventCallback:", 'event': event};
      postPlayerFacadeMessage(message);
   }
   /**
    * Saves the current playback state, most likely before starting a new ad-break
    * @returns {SourceObject} Current content source and playhead progress
    */
   this.setCurrentContentSource = function _() {
      var message = {'name':"setCurrentContentSource"};
      postPlayerFacadeMessage(message);
   };
   /**
    * @returns {SourceObject} Current content source and playhead progress
    */
   this.getCurrentContentSource = function _() {
      return callNativeFunction("getCurrentContentSource", null);
   };
   /**
    * Resets the latest known content source and playhead progress
    * @returns {Promise} Either resolves if the player accepted the play request or not
    */
   this.resetCurrentContentSource = function _() {
      let accept = callNativeFunction("resetCurrentContentSource", null);;
      return Promise.resolve(accept);
   };
   /**
    * Requests details about the most recent error that has occurred on the video player.
    * @returns {MediaError} Description object of the most recent error or `null`.
    */
   this.getError = function _() {
      let error = callNativeFunction("getError", null);
      console.log("error: " + error);
      return error;
   };
   this.getCurrentTime = function _() {
      let currentTime = callNativeFunction("getCurrentTime", null);
      console.log("currentTime: " + currentTime);
      return parseFloat(currentTime);
   };
   this.getDuration = function _() {
      let duration = callNativeFunction("getDuration", null);
      console.log("duration: " + duration);
      return parseFloat(duration);
   };
   this.getVideoElement = function _() {
      return callNativeFunction("getVideoElement", null);
   };
   this.getVolume = function _() {
      let volume = callNativeFunction("getVolume", null);
      console.log("volume: " + volume);
      return parseFloat(volume);
   };
   this.setVolume = function _(volume) {
      var message = {'name':"setVolume:", 'volume': volume};
      postPlayerFacadeMessage(message);
   };
   this.isMuted = function _() {
      return callNativeFunction("isMuted", null);
   };
   this.mute = function _() {
      postPlayerFacadeMessage("mute");
   };
   this.unmute = function _() {
      postPlayerFacadeMessage("unmute");
   };
   this.isPaused = function _() {
      return callNativeFunction("isPaused", null);
   };
   this.pause = function _() {
      postPlayerFacadeMessage("pausePlayback");
   };
   this.play = function _() {
      postPlayerFacadeMessage("startPlayback");
   };
   this.seek = function _(offset) {
      var message = {'name':"seek:", 'offset': offset};
      postPlayerFacadeMessage(message);
   };
}
