//
//  SCOutstreamBaseViewContr.swift
//  Smartclipios-app-demo
//
//  Copyright © 2019 spotx. All rights reserved.
//

import UIKit
import SmartclipSDKiOS

/**
 This is an example of how a base class of your outstream view controller could
 look like and how it interacts with the SpotX SDK.
**/
class SCOutstreamBaseViewController: UIViewController {
    @IBOutlet weak var contentView: SCAdContentView!
    var adController: SCAdController?

    override func viewDidLoad() {
        super.viewDidLoad()
        adController = SCAdController.init(sessionStateListener: self as SCAdSessionStateListener)
        adController?.delegate = self
        adController?.setContentView(self.contentView)
    }

    func startAdSlot(with url: String?, opener: String?, closer: String?, bumper: String?, breakPosition: SCBreakPosition) {
        if let advertisementUrl = url {
            let macros = SCAdMacros.init()

            // we are only using the default macro settings here,
            // you should set your desired values on the macros object
            macros.breakPosition = breakPosition
            macros.appBundle = Bundle.main.bundleIdentifier!

            let environment = SCAdEnvironment.init(macros: macros)
            environment.desiredBitrate = 2000
            environment.desiredMimeTypes = ["video/mp4"]

            let config = SCAdConfiguration.defaultOutstreamConfiguration(with: environment)
            config.adURL = advertisementUrl
            config.variants = SCAdVariants.init(opener: opener, closer: closer, bumper: bumper)

            config.customTitle = "Werbung"
            config.customTitleColor = UIColor.yellow
            config.customProgressBarColor = UIColor.yellow
            config.skipOffset = 3
            config.clickType = ClickableWithConfirmationDialog

            config.soundButtonOnImageName = "Sound_on"
            config.soundButtonOffImageName = "Sound_off"
            config.onEndBehavior = Collapse

/* if you want adVerification, then add your partnerName and omidVersion like this:
//
//         config.omidVersion = String(SmartclipSDKiOSVersionNumber)
//         config.omidPartnerName = "Smartclip"
//
*/
            
            adController?.startAdSlot(with: config)
        }
    }

    //override point for starting playback
    func startPlayback() {}

    //override point for finished advertisement playback
    func adSlotStarted() {
        self.contentView.invalidateIntrinsicContentSize()
    }

    //override point for finished advertisement playback
    func adSlotFinished() {
    }

    func displayAlert(tite:String?, message:String?) {
        let alertController = UIAlertController.init(title: tite, message: message, preferredStyle: .alert)
        let action = UIAlertAction.init(title: "OK", style: .cancel, handler: nil)
        alertController.addAction(action)
        self.present(alertController, animated: true, completion: nil)
    }
}

extension SCOutstreamBaseViewController: SCAdSessionStateListener {
    func onSDKReady() {
        startPlayback()
    }
}

//MARK: SCAdSlotControllerDelegate functions, override if needed
extension SCOutstreamBaseViewController: SCAdListener {
    ///override point for changed presentationSize (Called when the presentationSize of the AVItem changes)
    func presentationSizeChanged(to newSize: CGSize) {
    }

    func visibilityChanged(_ visible: Bool) {
        if !visible {
            adController?.pausePlayback()
        } else {
            adController?.startPlayback()
        }
    }

    func contentVideoError(_ error: Error!) {
        displayAlert(tite: "Content Video Error!",
                     message: String(format: "An error occured while trying to display the desired content video. \nMessage: %@", error.localizedDescription));
    }
    
    ///This function is being called by the SCTVOSSDK for
    ///every event that is being fired during the existance of an ad slot
    func onEventCallback(with event:SCAdEvent) {
        switch event.type {
        case ON_AD_SLOT_STARTED:
            adSlotStarted()
        case ON_AD_SLOT_FINISHED:
            adSlotFinished()
        case ON_AD_ERROR:
            adController?.getAdError { (adError) in
                if let unwrappedAdError = adError {
                    NSLog("adError: \(unwrappedAdError.errorDescription) code: \(unwrappedAdError.errorCode)")
                }
            }
            break
//            displayAlert(tite: "Ad Error!", message: "An error occured while trying to display the desired advertisement.")
        default:
            break
        }

        /// Uncomment this to receive the detailed SCAdInfo object:
        //*------------------------------------------------------------
//        adController.getAdInfo { (adInfo) in
//            if let unwrappedAdInfo = adInfo,
//                let description = unwrappedAdInfo.adInfoDescription() {
//                NSLog("adInfo: \(description)")
//            }
//        }
        //*------------------------------------------------------------
    }

    func displayClickThroughAlert(_ alert: UIAlertController!) {
        self.present(alert, animated: true, completion: nil)
    }
}
